@@ -63,16 +63,6 @@ gail_boolean_cell_factory_class_init (GailBooleanCellFactoryClass *klass)
   class->get_accessible_type = gail_boolean_cell_factory_get_accessible_type;
 }
 
-AtkObjectFactory*
-gail_boolean_cell_factory_new ()
-{
-  GObject *factory;
-
-  factory = g_object_new (GAIL_TYPE_BOOLEAN_CELL_FACTORY, NULL);
-
-  return ATK_OBJECT_FACTORY (factory);
-} 
-
 static AtkObject* 
 gail_boolean_cell_factory_create_accessible (GObject     *obj)
 {
