@@ -1,5 +1,5 @@
 /* GAIL - The GNOME Accessibility Implementation Library
- * Copyright 2001 Sun Microsystems Inc.
+ * Copyright 2001, 2002, 2003 Sun Microsystems Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -265,6 +265,9 @@ gail_text_view_real_initialize (AtkObject *obj,
      (GCallback) _gail_text_view_mark_set_cb, view, NULL, 0);
   g_signal_connect_data (buffer, "changed",
      (GCallback) _gail_text_view_changed_cb, view, NULL, 0);
+
+  obj->role = ATK_ROLE_TEXT;
+
 }
 
 static void
@@ -274,7 +277,7 @@ gail_text_view_finalize (GObject            *object)
 
   g_object_unref (text_view->textutil);
   if (text_view->insert_notify_handler)
-    gtk_idle_remove (text_view->insert_notify_handler);
+    g_source_remove (text_view->insert_notify_handler);
 
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -292,8 +295,6 @@ gail_text_view_new (GtkWidget *widget)
   accessible = ATK_OBJECT (object);
   atk_object_initialize (accessible, widget);
 
-  accessible->role = ATK_ROLE_TEXT;
-
   return accessible;
 }
 
@@ -1414,7 +1415,7 @@ _gail_text_view_insert_text_cb (GtkTextBuffer *buffer,
        */
       if (gail_text_view->insert_notify_handler)
         {
-          gtk_idle_remove (gail_text_view->insert_notify_handler);
+          g_source_remove (gail_text_view->insert_notify_handler);
         }
       gail_text_view->insert_notify_handler = 0;
       insert_idle_handler (gail_text_view);
@@ -1448,7 +1449,7 @@ _gail_text_view_delete_range_cb (GtkTextBuffer *buffer,
   gail_text_view = GAIL_TEXT_VIEW (accessible);
   if (gail_text_view->insert_notify_handler)
     {
-      gtk_idle_remove (gail_text_view->insert_notify_handler);
+      g_source_remove (gail_text_view->insert_notify_handler);
       gail_text_view->insert_notify_handler = 0;
       if (gail_text_view->position == offset && 
           gail_text_view->length == length)
@@ -1543,7 +1544,7 @@ _gail_text_view_changed_cb (GtkTextBuffer *buffer,
     {
       if (!gail_text_view->insert_notify_handler)
         {
-          gail_text_view->insert_notify_handler = gtk_idle_add (insert_idle_handler, accessible);
+          gail_text_view->insert_notify_handler = g_idle_add (insert_idle_handler, accessible);
         }
       return;
     }
@@ -1608,7 +1609,7 @@ emit_text_caret_moved (GailTextView *gail_text_view,
    */
   if (gail_text_view->insert_notify_handler)
     {
-      gtk_idle_remove (gail_text_view->insert_notify_handler);
+      g_source_remove (gail_text_view->insert_notify_handler);
       gail_text_view->insert_notify_handler = 0;
       insert_idle_handler (gail_text_view);
     }
